@@ -4,7 +4,7 @@ package DBIx::SearchBuilder;
 use strict;
 use warnings;
 
-our $VERSION = "1.62";
+our $VERSION = "1.63";
 
 use Clone qw();
 use Encode qw();
@@ -134,6 +134,7 @@ sub CleanSlate {
     $self->{'first_row'}        = 0;
     $self->{'must_redo_search'} = 1;
     $self->{'show_rows'}        = 0;
+    $self->{'joins_are_distinct'} = 0;
     @{ $self->{'aliases'} } = ();
 
     delete $self->{$_} for qw(
@@ -437,7 +438,7 @@ sub BuildSelectQuery {
         $QueryString .= $clause;
         $QueryString .= $self->_OrderClause;
     }
-    elsif ($self->_isJoined) {
+    elsif ( !$self->{'joins_are_distinct'} && $self->_isJoined ) {
         $self->_DistinctQuery(\$QueryString);
     }
     else {
